package com.github.jfcloud.gene.lis.config;

import cn.hutool.db.Db;
import cn.hutool.db.Entity;
import cn.hutool.db.ds.simple.SimpleDataSource;
import cn.hutool.db.sql.SqlFormatter;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;
import java.util.function.Consumer;

@Slf4j
@Component
public class LisDb {

    @Value("${lis.enable:false}")
    private boolean enable;

    private SimpleDataSource dataSource;

    public LisDb(LisDbProperty lisDbProperty) {
        if (lisDbProperty == null) {
            return;
        }
        dataSource = new SimpleDataSource(lisDbProperty.getUrl(), lisDbProperty.getUsername(), lisDbProperty.getPassword());
    }

    private Db getDb() {
        if (dataSource == null) {
            throw new RuntimeException("LIS数据库未配置");
        }
        return Db.use(dataSource);
    }

    /**
     * 查询
     *
     * @param sql
     * @return
     */
    @SneakyThrows
    public List<Entity> query(String sql) {
        try {
            log.info("【LIS查询列表】：\n{}", SqlFormatter.format(sql));
            return getDb().query(sql);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Collections.emptyList();
        }
    }

    /**
     * 查询单条记录
     *
     * @param sql
     * @return
     */
    @SneakyThrows
    public Entity queryOne(String sql) {
        log.info("【LIS查询单条】：\n{}", SqlFormatter.format(sql));
        return getDb().queryOne(sql);
    }

    /**
     * 执行，用事务方式执行
     *
     * @param consumer
     */
    @SneakyThrows
    public void execute(Consumer<Db> consumer) {
        if (!enable) {
            log.info("LIS未启用，不执行sql语句");
            return;
        }
        getDb().tx(consumer::accept);
    }
}
