package com.github.jfcloud.gene.sample.entity;

import cn.hutool.core.util.StrUtil;
import com.github.jfcloud.gene.common.entity.BaseEntity;
import com.github.jfcloud.gene.sample.enums.SampleTypeEnum;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.time.LocalDateTime;
import java.util.Objects;

@Accessors(chain = true)
@EqualsAndHashCode(callSuper = true)
@Data
public class SampleInfo extends BaseEntity {

    private Long id;

    @Schema(description = "项目名称")
    private String projectName;

    @Schema(description = "项目编号")
    private String projectNo;

    @Schema(description = "类型：病理pathological 动物样本检测animal 动物影像检测animalImage")
    private String type;

    @Schema(description = "状态")
    private String status;

    @Schema(description = "申请人id")
    private Long applicantId;

    @Schema(description = "申请人名称")
    private String applicantName;

    @Schema(description = "申请人电话")
    private String applicantPhone;

    @Schema(description = "申请人邮箱")
    private String applicantEmail;

    @Schema(description = "接收人id")
    private Long receiveUserId;

    @Schema(description = "接收人姓名")
    private String receiveUserName;

    @Schema(description = "申请时间")
    private LocalDateTime applyTime;

    @Schema(description = "检测人员")
    private String inspector;

    @Schema(description = "备注")
    private String remark;

    @Schema(description = "部门负责人Id")
    private Long departLeaderId;

    @Schema(description = "部门负责人姓名")
    private String departLeaderName;

    @Schema(description = "项目管理部审核人")
    private Long projectManageId;

    @Schema(description = "项目管理部审核人姓名")
    private String projectManageName;

    @Schema(description = "批准编号")
    private String approvalNo;

    @Schema(description = "修订号")
    private String revisionNo;

    @Schema(description = "收件日期")
    private String receiptDate;

    @Schema(description = "批准日期")
    private String approvalDate;

    @Schema(description = "失效日期")
    private String expireDate;

    @Schema(description = "科研Id")
    private Long kyId;

    @Schema(description = "提交版本号")
    private Integer version;

    /**
     * 消息通知 项目编号
     * @return
     */
    public String projectType() {
        String projectType = "样本送检/" + Objects.requireNonNull(SampleTypeEnum.resolve(getType())).getLabel();
        String proNo = StrUtil.emptyToDefault(getProjectNo(), getApprovalNo());
        if (StrUtil.isNotBlank(proNo)) {
            projectType += "/" + proNo;
        }
        if (StrUtil.isNotBlank(getProjectName())) {
            projectType += "/" + getProjectName();
        }

        return projectType;
    }

}